# coding: utf-8

"""
    GroupDocs.Translation SDK

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 24.3.0
    Contact: anton.perhunov@aspose.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Dict, List, Optional, Union
from pydantic import BaseModel, Field, StrictBytes, StrictInt, StrictStr, conlist, constr, validator
from groupdocs_translation_cloud.models.worksheet_data import WorksheetData

class SpreadsheetFileRequest(BaseModel):
    """
    Request for spreadsheet files, like xls, xlsx, xlsm, ods
    """
    source_language: constr(strict=True, min_length=1) = Field(..., alias="sourceLanguage", description="Language of original file")
    target_languages: conlist(StrictStr) = Field(..., alias="targetLanguages", description="List of target languages")
    file: Optional[Union[StrictBytes, StrictStr]] = Field(None, description="File as byte array")
    original_file_name: Optional[StrictStr] = Field(None, alias="originalFileName", description="Type in the file name. If null will be as request ID.")
    url: Optional[StrictStr] = Field(None, description="Link to file for translation. Ignore, if \"file\" property not null")
    origin: Optional[StrictStr] = Field(None, description="Url or name of application using this SDK. Not required.")
    saving_mode: Optional[StrictStr] = Field(None, alias="savingMode", description="Toggle file saving mode for storage.  Is Files by default.")
    format: StrictStr = Field(..., description="Input file format")
    output_format: StrictStr = Field(..., alias="outputFormat", description="output file format")
    worksheets: Optional[conlist(StrictInt)] = Field(None, description="List of Worksheets to translate by sequence number (1-based index). If not present, translate all worksheets")
    ranges: Optional[Dict[str, WorksheetData]] = Field(None, description="Dictionary of ranges in Excel workbooks")
    __properties = ["sourceLanguage", "targetLanguages", "file", "originalFileName", "url", "origin", "savingMode", "format", "outputFormat", "worksheets", "ranges"]

    @validator('saving_mode')
    def saving_mode_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('Files', 'Archive', 'Both'):
            raise ValueError("must be one of enum values ('Files', 'Archive', 'Both')")
        return value

    @validator('format')
    def format_validate_enum(cls, value):
        """Validates the enum"""
        if value not in ('Unknown', 'Xls', 'Xlsx', 'Xlsm', 'Ods'):
            raise ValueError("must be one of enum values ('Unknown', 'Xls', 'Xlsx', 'Xlsm', 'Ods')")
        return value

    @validator('output_format')
    def output_format_validate_enum(cls, value):
        """Validates the enum"""
        if value not in ('Xls', 'Xlsx', 'Xlsm', 'Xlsb', 'Html', 'Pdf', 'Xps', 'Ods', 'Md', 'Docx', 'Pptx', 'Tiff'):
            raise ValueError("must be one of enum values ('Xls', 'Xlsx', 'Xlsm', 'Xlsb', 'Html', 'Pdf', 'Xps', 'Ods', 'Md', 'Docx', 'Pptx', 'Tiff')")
        return value

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> SpreadsheetFileRequest:
        """Create an instance of SpreadsheetFileRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each value in ranges (dict)
        _field_dict = {}
        if self.ranges:
            for _key in self.ranges:
                if self.ranges[_key]:
                    _field_dict[_key] = self.ranges[_key].to_dict()
            _dict['ranges'] = _field_dict
        # set to None if file (nullable) is None
        # and __fields_set__ contains the field
        if self.file is None and "file" in self.__fields_set__:
            _dict['file'] = None

        # set to None if original_file_name (nullable) is None
        # and __fields_set__ contains the field
        if self.original_file_name is None and "original_file_name" in self.__fields_set__:
            _dict['originalFileName'] = None

        # set to None if url (nullable) is None
        # and __fields_set__ contains the field
        if self.url is None and "url" in self.__fields_set__:
            _dict['url'] = None

        # set to None if origin (nullable) is None
        # and __fields_set__ contains the field
        if self.origin is None and "origin" in self.__fields_set__:
            _dict['origin'] = None

        # set to None if worksheets (nullable) is None
        # and __fields_set__ contains the field
        if self.worksheets is None and "worksheets" in self.__fields_set__:
            _dict['worksheets'] = None

        # set to None if ranges (nullable) is None
        # and __fields_set__ contains the field
        if self.ranges is None and "ranges" in self.__fields_set__:
            _dict['ranges'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> SpreadsheetFileRequest:
        """Create an instance of SpreadsheetFileRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return SpreadsheetFileRequest.parse_obj(obj)

        _obj = SpreadsheetFileRequest.parse_obj({
            "source_language": obj.get("sourceLanguage") if obj.get("sourceLanguage") is not None else 'en',
            "target_languages": obj.get("targetLanguages"),
            "file": obj.get("file"),
            "original_file_name": obj.get("originalFileName"),
            "url": obj.get("url"),
            "origin": obj.get("origin"),
            "saving_mode": obj.get("savingMode"),
            "format": obj.get("format") if obj.get("format") is not None else 'Xlsx',
            "output_format": obj.get("outputFormat"),
            "worksheets": obj.get("worksheets"),
            "ranges": dict(
                (_k, WorksheetData.from_dict(_v))
                for _k, _v in obj.get("ranges").items()
            )
            if obj.get("ranges") is not None
            else None
        })
        return _obj

